(require (file "spur.scm"))
(require (file "phrase.scm"))

;;;  This is a variant of Piano Phase by Steve Reich via Andrew Sorensen.
;;;  It repeatedly plays 2 copies of a phrase, the 2nd drifting from the 1st.
;;;  Pitches and durations are fixed, but velocities are randomized (once).
;;;  The whole process takes about 434.16 secs (> 7 mins) to repeat.

;; the phrase to repeat
(define phrase
  (map (lambda (n) (set-note-vel n (rand 40 110)))       ; random velocities
       (string->phrase "C,D,G,A,Bb,D,C,A,G,D,Bb,A")))

;; tempo and timing
(define time-per-beat (* 180.0 *milli*))                 ; 180ms per beat
(define bpm (/ *minute* time-per-beat))
(define dur (* (phrase-length phrase) (/ time-per-beat 96)))

;; play the full phrase at the given time, then delay for delta and repeat
(define (play-repeat time chan delta)
  (schedule-phrase time chan phrase bpm)
  (schedule (+ time (* dur .8)) play-repeat (+ time dur delta) chan delta) )

(define (main) 
  (with-midi-schedule
    (define time (+ (now) (* .5 *second*)))  ; allow .5 seconds for setup
    (play-repeat time 1 0.0)                 ; play with no delay on channel 1
    (play-repeat time 2 (* 10.8 *milli*)) )) ; play with a short delay on ch 2
